@@ -1,9 +1,18 @@
 from typing import Dict, List, Optional
 
-from pydantic import BaseModel, StrictStr, root_validator
+from pydantic import BaseModel, Field, StrictStr, root_validator
 
 
-class MetaFilter(BaseModel):
+class HashableBaseModel(BaseModel):
+    """Hashable BaseModel https://github.com/pydantic/pydantic/issues/1303"""
+
+    def __hash__(self) -> int:
+        hashable_vals = [i for i in self.__dict__.values() if not isinstance(i, list)]
+        unhashables = [tuple(i) for i in self.__dict__.values() if isinstance(i, list)]
+        return hash((type(self),) + tuple(hashable_vals + unhashables))
+
+
+class MetaFilter(HashableBaseModel):
     """A class for filtering arbitrary metadata dataframe columns
 
     For example, to filter on a logged metadata column, "is_happy" for values [True],
@@ -20,7 +29,7 @@ class MetaFilter(BaseModel):
     isin: Optional[List[str]] = None
 
 
-class InferenceFilter(BaseModel):
+class InferenceFilter(HashableBaseModel):
     """A class for filtering an inference split
 
     - `is_otb`: Filters samples that are / are not On-The-Boundary
@@ -31,7 +40,7 @@ class InferenceFilter(BaseModel):
     is_drifted: Optional[bool] = None
 
 
-class LassoSelection(BaseModel):
+class LassoSelection(HashableBaseModel):
     """Representation of a lasso selection (used during an embeddings selection)
 
     x and y correspond to the cursor movement while tracing the lasso. This is natively
@@ -50,7 +59,7 @@ class LassoSelection(BaseModel):
         return values
 
 
-class FilterParams(BaseModel):
+class FilterParams(HashableBaseModel):
     """A class for sending filters to the API alongside most any request.
 
     Each field represents things you can filter the dataframe on.
@@ -73,6 +82,14 @@ class FilterParams(BaseModel):
         exclude_ids: List[int] = []  opposite of `ids`
         lasso: Optional[LassoSelection] = None  see LassoSelection class
         class_filter: Optional[List[StrictStr]] = None  filter GT OR prediction
+        likely_mislabeled: Optional[List[StrictStr]] = None  Filter for only
+            likely_mislabeled samples. False/None will return all samples
+        likely_mislabeled_dep_percentile: Optional[int] A percentile threshold for l
+            ikely mislabeled. This field (ranged 0-100) determines the precision of the
+            likely_mislabeled filter. The threshold is applied against the DEP
+            distribution of the likely_mislabeled samples. A threshold of 0 returns all,
+            100 returns 1 sample, and 50 will return the top 50% DEP samples that are
+            likely_mislabeled. Higher = more precision, lower = more recall. Default 50.
     """
 
     ids: List[int] = []
@@ -94,3 +111,4 @@ class FilterParams(BaseModel):
     lasso: Optional[LassoSelection] = None
     class_filter: Optional[List[StrictStr]] = None
     likely_mislabeled: Optional[bool] = None
+    likely_mislabeled_dep_percentile: Optional[int] = Field(50, ge=0, le=100)
